pub struct Ntfs { /* private fields */ }Expand description
Root structure describing an NTFS filesystem.
Implementations
Creates a new Ntfs object from a reader and validates its boot sector information.
The reader must cover the entire NTFS partition, not more and not less. It will be rewinded to the beginning before reading anything.
Returns the size of a single cluster, in bytes.
Returns the NtfsFile for the given NTFS File Record Number.
The first few NTFS files have fixed indexes and contain filesystem
management information (see the KnownNtfsFileRecordNumber enum).
Returns the size of a File Record of this NTFS filesystem, in bytes.
Returns the absolute byte position of the Master File Table (MFT).
Reads the $UpCase file from the filesystem and stores it in this Ntfs object.
This function only needs to be called if case-insensitive comparisons are later performed (i.e. finding files).
Returns the root directory of this NTFS volume as an NtfsFile.
Returns the size of a single sector in bytes.
Returns the 64-bit serial number of this NTFS volume.
pub fn volume_info<T>(&self, fs: &mut T) -> Result<NtfsVolumeInformation> where
T: Read + Seek,
pub fn volume_info<T>(&self, fs: &mut T) -> Result<NtfsVolumeInformation> where
T: Read + Seek,
Returns an NtfsVolumeInformation containing general information about
the volume, like the NTFS version.
pub fn volume_name<T>(&self, fs: &mut T) -> Option<Result<NtfsVolumeName>> where
T: Read + Seek,
pub fn volume_name<T>(&self, fs: &mut T) -> Option<Result<NtfsVolumeName>> where
T: Read + Seek,
Returns an NtfsVolumeName to read the volume name (also called volume label)
of this NTFS volume.
Note that a volume may also have no label, which is why the return value is further
encapsulated in an Option.